from dataclasses import dataclass


@dataclass
class Item:
    ItemId: str
    ItemCode: str
    Name: str
    Description: str
    BasePrice: int
    BasePriceDlvr: int
    PhotoURLs: list[str]
    Sequence: float
    ModifierGroup: list["ModifierGroup"]
    PMTNo: str
    PMTRefNo: str
    PMTAmount: int
    PMTLine: int
    IsMOP: bool
    IsDelivery: bool
    IsInventoried: bool
    IsFeatured: bool
    IsScheduled: bool
    IsDineIn: bool


@dataclass
class ModifierGroup:
    menu_id: str
    name: str
    description: str
    photo_urls: list[str]
    sequence: float
    selection_range_min: int
    selection_range_max: int
    is_fixed_price: bool
    is_free: bool
    is_quantifiable: bool
    uom: str
    modifiers: list["Modifier"]


@dataclass
class Modifier:
    ItemCode: str
    Name: str
    FilterCode: str
    UnitPrice: int
    UnitPriceDlvr: int
    Sequence: float
    SelectionRangeMin: int
    SelectionRangeMax: int
    IsFixedPrice: bool
    IsFree: bool
    IsQuantifiable: bool
    IsDefault: bool
    UOM: str
    PhotoURLs: list[str]
    DefaultKeys: list[str]
    DefaultValues: list[str]



import requests

from .models import Item, Store


class Starbucks:
    """The main class to instantiate to access Starbucks API."""

    def __init__(self):
        self.api_base_url = "https://static.sbux.mobi"
        self.headers = {"user-agent": "starbucksSG/330 CFNEtwork/1399 Darwin/22.1.0"}

    def get_stores(self) -> list[Store]:
        """Retrieves a list of stores from the Starbucks API."""
        url = f"{self.api_base_url}/json/mop/stores.json"
        response = requests.get(url, headers=self.headers)

        return self._parse_get_stores(response)

    def _parse_get_stores(self, response: requests.Response) -> list[Store]:
        """Parses the response from a 'get_stores' request and returns a list of Store objects."""
        stores_data = response.json()["Data"]

        return [Store(**store) for store in stores_data]

    def get_menu_items(self, store_id: str) -> list[Item]:
        """Retrieves a list of menu items for a given store from the Starbucks API."""
        url = f"{self.api_base_url}/json/mop/menu/{store_id}.json"
        response = requests.get(url, headers=self.headers)

        return self._parse_get_menu_items(response)

    def _parse_get_menu_items(self, response: requests.Response) -> list[Item]:
        """Parses the response from a 'get_menu_items' request and returns a list of Item objects."""
        menu_data = response.json()["Data"][0]["Items"]

        return [Item(**item) for item in menu_data]



from dataclasses import dataclass


@dataclass
class Store:
    BranchCode: str
    OutletCode: str
    StoreCode: str
    StoreName: str
    Address: str
    PostalCode: str
    PhoneNo: str
    Longitude: str
    Latitude: str
    MONPStatus: bool
    DeliveryStatus: bool
    ServiceHours: list["ServiceHour"]
    Amenities: "Amenities"


@dataclass
class ServiceHour:
    DayOfWeekString: str
    DayOfWeek: int
    OpenFrom: str
    OpenTo: str
    Is24Hours: bool
    IsClosed: bool


@dataclass
class Amenities:
    NitroColdBrew: bool
    StarbucksReserve: bool
    MobileOrderandPay: bool
    FreeWifi: bool
    PourOverBrew: bool



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['sbux', 'sbux.models']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.28.1,<3.0.0']

setup_kwargs = {
    'name': 'sbux',
    'version': '0.1.0',
    'description': 'An unofficial Starbucks Singapore (SG) software development kit (SDK).',
    'long_description': '# sbux\n\n`sbux` is an unofficial Starbucks Singapore (SG) software development kit (SDK). SBUX is the ticker symbol of Starbucks Corporation on the NASDAQ.\n\n## Installing\n\nInstall and update using `pip`;\n\n```sh\npip install sbux\n```\n\n## A Simple Example\n\n```python\nfrom sbux import Starbucks\n\napp = Starbucks\napp.get_stores()\napp.get_menu_items(store_id="13377")\n```\n\n## Contributing\n\nFor guidance on setting up a development environment and how to make a contribution, see the [contributing guidelines](./docs/CONTRIBUTING.md).\n',
    'author': 'Jerry Ng',
    'author_email': 'ngshiheng@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/ngshiheng/sbux',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
